@@ -1,7 +1,8 @@
 'use strict'
 
 const debug = require('debug')('nock.common')
-const set = require('lodash.set')
+const isPlainObject = require('lodash/isPlainObject')
+const set = require('lodash/set')
 const timers = require('timers')
 const url = require('url')
 const util = require('util')
@@ -608,51 +609,6 @@ function deepEqual(expected, actual) {
   return expected === actual
 }
 
-/**
- * Checks if `value` is a plain object, that is, an object created by the
- * `Object` constructor or one with a `[[Prototype]]` of `null`.
- * https://github.com/lodash/lodash/blob/588bf3e20db0ae039a822a14a8fa238c5b298e65/isPlainObject.js
- *
- * @param {*} value The value to check.
- * @return {boolean}
- */
-function isPlainObject(value) {
-  const isObjectLike = typeof value === 'object' && value !== null
-  const tag = Object.prototype.toString.call(value)
-  if (!isObjectLike || tag !== '[object Object]') {
-    return false
-  }
-  if (Object.getPrototypeOf(value) === null) {
-    return true
-  }
-  let proto = value
-  while (Object.getPrototypeOf(proto) !== null) {
-    proto = Object.getPrototypeOf(proto)
-  }
-  return Object.getPrototypeOf(value) === proto
-}
-
-/**
- * Creates an object with the same keys as `object` and values generated
- * by running each own enumerable string keyed property of `object` thru
- * `iteratee`. (iteration order is not guaranteed)
- * The iteratee is invoked with three arguments: (value, key, object).
- * https://github.com/lodash/lodash/blob/588bf3e20db0ae039a822a14a8fa238c5b298e65/mapValue.js
- *
- * @param {Object} object The object to iterate over.
- * @param {Function} iteratee The function invoked per iteration.
- * @returns {Object} Returns the new mapped object.
- */
-function mapValue(object, iteratee) {
-  object = Object(object)
-  const result = {}
-
-  Object.keys(object).forEach(key => {
-    result[key] = iteratee(object[key], key, object)
-  })
-  return result
-}
-
 const timeouts = []
 const intervals = []
 const immediates = []
@@ -725,7 +681,6 @@ module.exports = {
   isRequestDestroyed,
   isStream,
   isUtf8Representable,
-  mapValue,
   matchStringOrRegexp,
   normalizeClientRequestArgs,
   normalizeOrigin,
